# Contributor's Agreement

This code is licensed under the MPL 2.0 [LICENSE](LICENSE).

# Contributing

When contributing to FreeGenes Python, it is important to properly communicate the
gist of the contribution. If it is a simple code or editorial fix, simply
explaining this within the GitHub Pull Request (PR) will suffice. But if this
is a larger fix or enhancement, it should be first discussed with the project
leader or developers.

Please note we have a [code of conduct](CODE_OF_CONDUCT.md) that you should follow in
all your interactions with the project members and users.

## Pull Request Process

1. Send PRs to the master branch for merge as a pypi release.
2. Follow the existing code style precedent to the best of your ability.
3. Test your PR locally, and provide the steps necessary to test for the reviewers.
4. The project's default copyright and header have been included in any new source files.
5. All (major) changes must be documented in [docs](../docs).
6. If necessary, update the README.md and CHANGELOG.md in the root of the repository.
7. The pull request will be reviewed by others, and the final merge must be
   done by the project lead, @vsoch (or approved by her).
